@@ -598,12 +598,18 @@ void NMainMenuBar::setupShortcut(QAction *action, QString text) {
 
 
 void NMainMenuBar::openManual() {
+#ifndef _WIN32
     QDesktopServices::openUrl(QString("file://") +
-                              global.getProgramDirPath()+"/help/UserDocumentation.pdf");
+                             global.getProgramDirPath()+"/help/UserDocumentation.pdf");
+#else
+    QDesktopServices::openUrl(QString("file:///") +
+                             global.getProgramDirPath().replace("\\","/")+"/help/UserDocumentation.pdf");
+#endif
 }
 
 
 
+
 void NMainMenuBar::openUserForum() {
     QDesktopServices::openUrl(QUrl("https://discussion.evernote.com/index.php"));
 }
