@@ -29,6 +29,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QIcon>
 #include <QMessageBox>
 
+
+#ifdef _WIN32
+#include <tidy/tidybuffio.h>
+#endif
+
+
 #include <iostream>
 using namespace std;
 
@@ -198,9 +204,8 @@ QByteArray EnmlFormatter::rebuildNoteEnml() {
     // Strip off HTML header & remove the background & default font color
     // if they match the theme default.
     index = content.indexOf("<body");
-    QLOG_DEBUG() << content;
-    QString header = content.mid(index);
-    QByteArray c1 = content.mid(0,index);
+    QString header = content.mid(0,index);
+    QByteArray c1 = content.mid(index);
     index = header.indexOf(">");
     header = header.mid(0,index);
     QByteArray c2 = content.mid(content.indexOf(">",index));
@@ -211,8 +216,6 @@ QByteArray EnmlFormatter::rebuildNoteEnml() {
     newHeader = newHeader.replace(fgColor,"");
     content = c1;
     content.append(newHeader).append(c2);
-    QLOG_DEBUG() << content;
-
 
     // Start transforming the header
     index = content.indexOf("<body");
@@ -237,35 +240,117 @@ QByteArray EnmlFormatter::rebuildNoteEnml() {
     content = content.replace("<ac:rich-text-body", "<div");
     content = content.replace("</ac:rich-text-body", "</div");
 
+
+#ifndef _WIN32
+    bool useLegacyTidy = true;
+#else
     // Run it through "tidy".  It is a program which will fix any invalid HTML
     // and give us the results back through stdout.  In a perfect world this
     // wouldn't be needed, but WebKit doesn't always give back good HTML.
-    QProcess tidyProcess;
-    tidyProcess.start("tidy -raw -asxhtml -q -m -u -utf8 ", QIODevice::ReadWrite|QIODevice::Unbuffered);
-    QLOG_DEBUG() << "Starting tidy " << tidyProcess.waitForStarted();
-    tidyProcess.waitForStarted();
-    tidyProcess.write(content);
-    tidyProcess.closeWriteChannel();
-    tidyProcess.waitForFinished();
-    QLOG_DEBUG() << "Stopping tidy " << tidyProcess.waitForFinished() << " Return Code: " << tidyProcess.state();
-    QString errors(tidyProcess.readAllStandardError());
-    QStringList errorList = errors.split("\n");
-    for (int e=0; e<errorList.size(); e++) {
-        if (not errorList[e].contains("<img> proprietary attribute \"type\"") &&
-            not errorList[e].contains("<img> proprietary attribute \"oncontextmenu\"") &&
-            not errorList[e].contains("<img> proprietary attribute \"hash\"") &&
-            not errorList[e].contains("<img> proprietary attribute \"en-tag\"") &&
-            not errorList[e].contains("<img> proprietary attribute \"lid\"") &&
-            not errorList[e].contains("<img> proprietary attribute \"oncontextmenu\"") &&
-            not errorList[e].contains("<img> lacks \"alt\" attribute")
-            ) {
-                QLOG_INFO() << errorList[e];
+    bool useLegacyTidy = false;
+
+    if (global.useLibTidy && !global.bypassTidy) {
+        TidyBuffer output;
+        memset(&output, 0, sizeof(output));
+        TidyBuffer errout;
+        memset(&errout, 0, sizeof(errout));
+
+        int tidyRc;
+        bool ok;
+
+        TidyDoc tdoc = tidyCreate();
+        ok = tidyOptSetBool(tdoc, TidyXmlOut, yes);
+        if (!ok) {
+            QLOG_ERROR() << "Error using tidyOptSetBool: " << ok;
+            useLegacyTidy=true;
+        } else {
+            tidyRc = tidySetInCharEncoding(tdoc,"utf8");
+            if (tidyRc>=2 || tidyRc < 0) {
+                QLOG_ERROR() << "Error using tidySetInCharEncoding: " << tidyRc;
+                useLegacyTidy=true;
+            } else {
+                tidyRc = tidySetOutCharEncoding(tdoc, "utf8");
+                if (tidyRc>=2 || tidyRc < 0) {
+                    QLOG_ERROR() << "Error using tidyOutInCharEncoding: " << tidyRc;
+                    useLegacyTidy=true;
+                } else {
+                    tidyRc = tidySetErrorBuffer(tdoc, &errout);
+                    if (tidyRc>=2 || tidyRc < 0) {
+                        QLOG_ERROR() << "Error using tidySetErrorBuffer: " << tidyRc;
+                        useLegacyTidy=true;
+                    } else {
+                        QByteArray tarray = content;
+                        char * buffer;
+                        buffer = new char[tarray.size()+1];
+                        strcpy(buffer, tarray.data());
+                        buffer[tarray.size()] = '\0';
+                        tidyRc = tidyParseString(tdoc, buffer);
+                        delete buffer;
+                        if (tidyRc>=2 || tidyRc < 0) {
+                            QLOG_ERROR() << "Error using tidyParseString: " << tidyRc;
+                            useLegacyTidy=true;
+                        } else {
+                            tidyRc = tidyCleanAndRepair(tdoc);
+                            if (tidyRc>=2 || tidyRc < 0) {
+                                QLOG_ERROR() << "Error using tidyCleanAndRepair: " << tidyRc;
+                                useLegacyTidy=true;
+                            } else {
+                                tidyRc = tidySaveBuffer(tdoc, &output);
+                                if (tidyRc>=2 || tidyRc < 0) {
+                                    QLOG_ERROR() << "Error using tidySaveBuffer: " << tidyRc;
+                                    useLegacyTidy=true;
+                                } else {
+                                    content.clear();
+                                    content.append((const char*)output.bp, output.size);
+                                }
+                            }
+                        }
+                    }
+                }
+            }
         }
+        if (output.allocated)
+           tidyBufFree(&output);
+        if (errout.allocated)
+            tidyBufFree(&errout);
+        tidyRelease(tdoc);
+    }
+ #endif
+
+    // IF the new tidy had an error, or we choose to use the old method
+    if ((useLegacyTidy || !global.useLibTidy) && !global.bypassTidy) {
+        QLOG_DEBUG() << "Calling tidy";
+        QProcess tidyProcess;
+        tidyProcess.start("tidy -raw -asxhtml -q -m -u -utf8 ", QIODevice::ReadWrite|QIODevice::Unbuffered);
+        QLOG_DEBUG() << "Starting tidy " << tidyProcess.waitForStarted();
+        tidyProcess.waitForStarted();
+        tidyProcess.write(content);
+        tidyProcess.closeWriteChannel();
+        tidyProcess.waitForFinished();
+        QLOG_DEBUG() << "Stopping tidy " << tidyProcess.waitForFinished() << " Return Code: " << tidyProcess.state();
+        QString errors(tidyProcess.readAllStandardError());
+        QStringList errorList = errors.split("\n");
+        for (int e=0; e<errorList.size(); e++) {
+            if (not errorList[e].contains("<img> proprietary attribute \"type\"") &&
+                not errorList[e].contains("<img> proprietary attribute \"oncontextmenu\"") &&
+                not errorList[e].contains("<img> proprietary attribute \"hash\"") &&
+                not errorList[e].contains("<img> proprietary attribute \"en-tag\"") &&
+                not errorList[e].contains("<img> proprietary attribute \"lid\"") &&
+                not errorList[e].contains("<img> proprietary attribute \"oncontextmenu\"") &&
+                not errorList[e].contains("<img> lacks \"alt\" attribute")
+                ) {
+                    QLOG_DEBUG() << errorList[e];
+           }
+       }
+
+
+        QLOG_DEBUG() << "After tidy";
+        content.clear();
+        content.append(tidyProcess.readAllStandardOutput());
+        tidyProcess.close();
     }
 
-    content.clear();
-    content.append(tidyProcess.readAllStandardOutput());
-    tidyProcess.close();
+
     if (content == "") {
         formattingError = true;
         return "";
@@ -515,6 +600,8 @@ bool EnmlFormatter::isAttributeValid(QString attribute) {
 
 
 bool EnmlFormatter::isElementValid(QWebElement e) {
+    if (global.bypassTidy)
+        return true;
     QString element = e.tagName().toLower();
     //QLOG_DEBUG() << "Checking tag " << element;
     if (element == "a") {
